@@ -1526,7 +1526,7 @@ g_key_file_get_string_list (GKeyFile     *key_file,
           g_set_error (error, G_KEY_FILE_ERROR,
                        G_KEY_FILE_ERROR_INVALID_VALUE,
                        _("Key file contains key '%s' "
-                         "which has value that cannot be interpreted."),
+                         "which has a value that cannot be interpreted."),
                        key);
           g_error_free (key_file_error);
         }
@@ -1559,7 +1559,7 @@ g_key_file_get_string_list (GKeyFile     *key_file,
  * @length: number of string values in @list
  *
  * Associates a list of string values for @key under @group_name.
- * If @key cannot be found then it is created.  
+ * If @key cannot be found then it is created.
  * If @group_name cannot be found then it is created.
  *
  * Since: 2.6
@@ -1575,7 +1575,7 @@ g_key_file_set_string_list (GKeyFile            *key_file,
   gsize i;
 
   g_return_if_fail (key_file != NULL);
-  g_return_if_fail (list != NULL);
+  g_return_if_fail (list != NULL || length == 0);
 
   value_list = g_string_sized_new (length * 128);
   for (i = 0; i < length && list[i] != NULL; i++)
@@ -1601,7 +1601,7 @@ g_key_file_set_string_list (GKeyFile            *key_file,
  * @locale: a locale identifier
  * @string: a string
  *
- * Associates a string value for @key and @locale under @group_name.  
+ * Associates a string value for @key and @locale under @group_name.
  * If the translation for @key cannot be found then it is created.
  *
  * Since: 2.6
@@ -2526,8 +2526,6 @@ g_key_file_set_key_comment (GKeyFile     *key_file,
   tmp = key_node->next;
   while (tmp != NULL)
     {
-      GKeyFileKeyValuePair *pair;
-
       pair = (GKeyFileKeyValuePair *) tmp->data;
 
       if (pair->key != NULL)
@@ -2748,8 +2746,6 @@ g_key_file_get_key_comment (GKeyFile     *key_file,
 
   while (tmp != key_node)
     {
-      GKeyFileKeyValuePair *pair;
-      
       pair = (GKeyFileKeyValuePair *) tmp->data;
       
       if (string == NULL)
